@@ -21,11 +21,9 @@ Created date: 11/03/2021
 
 from infertrade.algos.community import infertrade_export
 from infertrade.algos.external.ta import ta_adaptor, ta_export
-from infertrade.algos.external.ta_lib import talib_adapter, talib_export
 
 # A dictionary providing the list of available rules from InferTrade's community rules and external packages.
 algorithm_functions = {
     "infertrade": infertrade_export,
     "ta": ta_export,
-    "ta-lib": talib_export,
 }
