@@ -20,11 +20,11 @@ Created date: 18th March 2021
 """
 
 # Python standard library
-
 from typing import List, Union
 from copy import deepcopy
 import pandas as pd
 
+# InferTrade packages
 from infertrade.algos import algorithm_functions, ta_adaptor
 from infertrade.utilities.operations import ReturnsFromPositions
 from infertrade.PandasEnum import PandasEnum
@@ -187,3 +187,45 @@ class Api:
         original_df = deepcopy(df)
         df_with_signal = class_of_signal_generator(original_df)
         return df_with_signal
+
+    @staticmethod
+    def get_available_representations(name_of_algorithm: str) -> List[str]:
+        """Describes which representations exist for the algorithm."""
+        dict_of_properties = Api.get_algorithm_information()
+        try:
+            available_representations = list(
+                dict_of_properties[name_of_algorithm]["available_representation_types"].keys()
+            )
+        except KeyError:
+            raise NotImplementedError("The requested algorithm does not have any representations: ", name_of_algorithm)
+        return available_representations
+
+    @staticmethod
+    def return_representations(
+        name_of_algorithm: str, representation_or_list_of_representations: Union[str, List[str]] = None
+    ) -> dict:
+        """Returns the representations (e.g. URLs of relevant documentation."""
+
+        if not representation_or_list_of_representations:
+            representation_or_list_of_representations = Api.get_available_representations()
+
+        dict_of_properties = Api.get_algorithm_information(name_of_algorithm)
+        representations = dict_of_properties[name_of_algorithm]["available_representation_types"]
+        if isinstance(representation_or_list_of_representations, list):
+            representation_dict = {}
+            for ii_entry in representation_or_list_of_representations:
+                if ii_entry in representations:
+                    representation_dict.update({ii_entry: representations[ii_entry]})
+                else:
+                    raise NameError("Could not find this representation: ", ii_entry)
+        elif isinstance(representation_or_list_of_representations, str):
+            try:
+                representation_dict = dict_of_properties[name_of_algorithm]["available_representation_types"][
+                    representation_or_list_of_representations
+                ]
+            except KeyError:
+                raise NameError("Could not find this representation: ", representation_or_list_of_representations)
+        else:
+            raise TypeError("Input type not supported: ", representation_or_list_of_representations)
+
+        return representation_dict
