@@ -22,10 +22,12 @@ Created date: 11/03/2021
 import numpy as np
 import pandas as pd
 
+from infertrade.PandasEnum import PandasEnum
+
 
 def simulated_market_data_4_years_gen():
     """This function creates ~4 years of simulated daily data for testing interfaces."""
-    # open,high,last,low,turnover,volume
+    # Creates data with open, high, last, low, turnover and volume.
     open = np.cumprod([1 + 0.1 * (np.random.random() - np.random.random()) for _ in range(1000)])
     high = open * [1 + 0.1 * (np.random.random()) for _ in range(1000)]
     low = open * [1 - 0.1 * (np.random.random()) for _ in range(1000)]
@@ -34,7 +36,7 @@ def simulated_market_data_4_years_gen():
     turnover = [100_000 + 10_000 * np.random.random() for _ in range(1000)]
     volume = [10_000 + 1000 * np.random.random() for _ in range(1000)]
     return pd.DataFrame(
-        {"open": open, "close": close, "high": high, "low": low, "last": last, "turnover": turnover, "volume": volume, "end_of_period_price": close}
+        {"open": open, "close": close, "high": high, "low": low, "last": last, "turnover": turnover, "volume": volume}
     )
 
 
@@ -44,4 +46,4 @@ def simulated_correlated_equities_4_years_gen():
     independent_asset = np.cumprod([1 + 0.02 * (np.random.random() - np.random.random()) for _ in range(1000)])
     asset_2 = asset_1 * independent_asset
 
-    return pd.DataFrame({"price": asset_1, "signal": asset_2,})
+    return pd.DataFrame({PandasEnum.PRICE.value: asset_1, PandasEnum.SIGNAL.value: asset_2,})
